@@ -1,11 +1,8 @@
-package DateTime::Format::MySQL;
+# we need to comment this out or PAUSE might index it
+# pack age DateTime::Format::MySQL;
 
 use strict;
 
-use vars qw ($VERSION);
-
-$VERSION = '0.03';
-
 use DateTime;
 
 # Builder relevant stuff starts here.
