@@ -1,11 +1,8 @@
-package DateTime::Format::W3CDTF;
+# we need to comment this out or PAUSE might index it
+# pack age DateTime::Format::W3CDTF;
 
 use strict;
 
-use vars qw ($VERSION);
-
-$VERSION = '0.03';
-
 use DateTime::Format::Builder
 (
     parsers => {
